summaryrefslogtreecommitdiffstats
path: root/akregator/src/librss/document.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /akregator/src/librss/document.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'akregator/src/librss/document.cpp')
-rw-r--r--akregator/src/librss/document.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/akregator/src/librss/document.cpp b/akregator/src/librss/document.cpp
index 170ceaa7e..696802ec7 100644
--- a/akregator/src/librss/document.cpp
+++ b/akregator/src/librss/document.cpp
@@ -105,7 +105,7 @@ Document::Document(const TQDomDocument &doc) : d(new Private)
else
d->valid=true;
- attr = rootNode.toElement().attribute(TQString::tqfromLatin1("version"), TQString::null);
+ attr = rootNode.toElement().attribute(TQString::tqfromLatin1("version"), TQString());
if (rootNode.toElement().tagName()==TQString::tqfromLatin1("feed"))
{
d->format=AtomFeed;
@@ -137,7 +137,7 @@ Document::Document(const TQDomDocument &doc) : d(new Private)
if (d->format==UnknownFormat)
{
- attr = rootNode.toElement().attribute(TQString::tqfromLatin1("xmlns"), TQString::null);
+ attr = rootNode.toElement().attribute(TQString::tqfromLatin1("xmlns"), TQString());
if (!attr.isNull()) {
/*
* Hardcoding these URLs is actually a bad idea, since the DTD doesn't
@@ -183,27 +183,27 @@ Document::Document(const TQDomDocument &doc) : d(new Private)
d->link = extractLink(channelNode, d->format);
/* This is ugly but necessary since RSS 0.90 and 1.0 have a different parent
* node for <image>, <textinput> and <item> than RSS 0.91-0.94 and RSS 2.0.
*/
- TQDomNode parentNode;
+ TQDomNode tqparentNode;
if (d->version == v0_90 || d->version == v1_0 || d->format == AtomFeed)
- parentNode = rootNode;
+ tqparentNode = rootNode;
else
{
// following is a HACK for broken 0.91 feeds like xanga.com's
if (!rootNode.namedItem(TQString::tqfromLatin1("item")).isNull())
- parentNode = rootNode;
+ tqparentNode = rootNode;
else
- parentNode = channelNode;
+ tqparentNode = channelNode;
}
// image and textinput aren't supported by Atom.. handle in case feed provides
- TQDomNode n = parentNode.namedItem(TQString::tqfromLatin1("image"));
+ TQDomNode n = tqparentNode.namedItem(TQString::tqfromLatin1("image"));
if (!n.isNull())
d->image = new Image(n);
- n = parentNode.namedItem(TQString::tqfromLatin1("textinput"));
+ n = tqparentNode.namedItem(TQString::tqfromLatin1("textinput"));
if (!n.isNull())
d->textInput = new TextInput(n);
@@ -214,7 +214,7 @@ Document::Document(const TQDomDocument &doc) : d(new Private)
else
tagName=TQString::tqfromLatin1("item");
- for (n = parentNode.firstChild(); !n.isNull(); n = n.nextSibling()) {
+ for (n = tqparentNode.firstChild(); !n.isNull(); n = n.nextSibling()) {
const TQDomElement e = n.toElement();
if (e.tagName() == tagName)
d->articles.append(Article(e, d->format, d->version));
@@ -224,7 +224,7 @@ Document::Document(const TQDomDocument &doc) : d(new Private)
d->copyright = elemText;
if (d->format == AtomFeed)
- elemText = rootNode.toElement().attribute(TQString::tqfromLatin1("xml:lang"), TQString::null);
+ elemText = rootNode.toElement().attribute(TQString::tqfromLatin1("xml:lang"), TQString());
else
elemText = extractNode(channelNode, TQString::tqfromLatin1("language"));
@@ -541,7 +541,7 @@ TQString Document::verbVersion() const
case vAtom_0_1: return TQString::tqfromLatin1("0.1");
case vAtom_1_0: return TQString::tqfromLatin1("1.0");
}
- return TQString::null;
+ return TQString();
}
TQString Document::title() const
@@ -183,27 +183,27 @@ Document::Document(const TQDomDocument &doc) : d(new Private)
d->link = extractLink(channelNode, d->format);
- /* This is ugly but necessary since RSS 0.90 and 1.0 have a different parent
+ /* This is ugly but necessary since RSS 0.90 and 1.0 have a different tqparent
* node for <image>, <textinput> and <item> than RSS 0.91-0.94 and RSS 2.0.
*/